#!/bin/bash

if [ $# == 0 ]; then
	echo "usage $0 <PYTHON_CMD> <numpy_site_cfg_file> <numpy_version>"
	exit 0
fi


umask 0022
#==================================================================
#MODIFY the following lines:
#==================================================================
START=`pwd`
#DIRECTORIES:
SCRATCH=$START/scratch
INST_DIR_BASE=/opt/sw/numpy
PYTHON="$1 -O"
NUMPY_SITE_CFG=$2
#VERSION NUMBERS:
NUMPY_VERSION=$3
#NUMPY_VERSION=1.6.2
#NUMPY_VERSION=1.5.1
NUMPY=numpy-${NUMPY_VERSION}
NUMPY_LOCATION=http://garr.dl.sourceforge.net/project/numpy/NumPy/${NUMPY_VERSION}/${NUMPY}.tar.gz
#==================================================================
#End of MODIFY
#==================================================================

#PREPARE:
PYTHON_VERSION=`$PYTHON -V 2>&1| cut -d ' ' -f 2| cut -d '.' -f 1,2`
INST_DIR=$INST_DIR_BASE/$NUMPY_VERSION
PYTHON_LIBS=$INST_DIR/lib64/python${PYTHON_VERSION}/site-packages
export PYTHONPATH=$PYTHON_LIBS:$PYTHONPATH
export PYTHONOPTIMIZE="1"
mkdir -p $INST_DIR/lib64
mkdir -p $SCRATCH

ln -s $INST_DIR/lib64 $INST_DIR/lib
rm log_*
mkdir -p $SCRATCH


#NUMPY
cd $SCRATCH
wget $NUMPY_LOCATION
rm -rf ${NUMPY}
tar zxf ${NUMPY}.tar.gz
cd ${NUMPY}
#for optimizing:
mv site.cfg site.cfg.orig
#this works at least for numpy 1.6.2 and 1.7.0
ln -s ${START}/${NUMPY_SITE_CFG} site.cfg
sed -i "s?self.cc_exe = 'icc -fPIC'?self.cc_exe = 'icc -O3 -g -fPIC -fp-model strict -fomit-frame-pointer -openmp -xhost'?"  numpy/distutils/intelccompiler.py
sed -i "s?'compiler_f90' : \[None\],?'compiler_f90' : \['-xhost','-openmp','-fp-model strict','-fPIC'\],?" ./numpy/distutils/fcompiler/intel.py
#changing compiler_f90 obviously is enough
#sed -i "s?'compiler_f77' : \[None, \"-FI\", \"-w90\", \"-w95\"\],?'compiler_f77' :  \['-xhost','-openmp','-fp-model strict','-fPIC'\],?" ./numpy/distutils/fcompiler/intel.py
#sed -i "s?'compiler_fix' : \[None, \"-FI\"\],?'compiler_fix' :  \['-xhost','-openmp','-fp-model strict','-fPIC'\],?" ./numpy/distutils/fcompiler/intel.py
#for 32bit environments
#${PYTHON} setup.py config --compiler=intel build_clib --compiler=intel build_ext --compiler=intel install --prefix=$INST_DIR &> $START/log_numpy
#for intel64 environments
${PYTHON} setup.py config --compiler=intelem build_clib --compiler=intelem build_ext --compiler=intelem install --prefix=$INST_DIR &> $START/log_numpy

echo ===================================================================================
echo add these paths to your .bashrc
echo
echo export PYTHONPATH=$PYTHON_LIBS:\$PYTHONPATH
echo ===================================================================================



